@echo OFF

rem SETINet.bat:  Refresh buffers for a single Cmd-n folder-tree on a remote machine
rem For version info, see BatFiles\SBVer.bat

if .%1.==./?. goto Help
if not .%1.==.?. goto NoHelp


:Help

   echo.
   echo.SETINet.bat %SB.ver% %SB.verdate%:  Expected Parameters:
   echo.
   echo.  1.  Drive: (colon required) to use for temporary drive mapping
   echo.  2.  \\Machine Name (\\ required), indicating the machine to be refreshed
   echo.  3.  Path on that machine to the SETI folder (e.g., SETI)
   echo.  4.  Instance base (e.g., Cmd-1); a folder with this name is tested for
   echo.
   echo.  The SETI folder is assumed to be the current directory
   echo.
   echo.  Function:  Send in any completed Work Units in active WU Buffers on a remote
   echo.             machine; get new Work Units to replace any sent in; and get new
   echo.             Work Units to fill any empty active WU Buffers.
   echo.
   echo.             SETI.ok/SETI.no settings are used to determine 'active' status.
   echo.
   pause
   goto Continue

:NoHelp


  rem Test for presence of BatFiles\SETIVfy.bat

   if exist BatFiles\SETIVfy.bat goto VFYok
   echo.
   echo.SETINet.bat %SB.ver% %SB.verdate%:
   echo.Improper installation:  cannot find BatFiles\SETIVfy.bat
   echo.
   set SB.Quit=SETINet.bat_cannot_find_SETIVfy.bat
   pause
   goto Continue

:VFYok


  rem Verify installation   

   call BatFiles\SETIVfy.bat SETINet.bat
   if not .%SB.Quit%.==.. goto Continue


  rem Verify Parameters

   call BatFiles\SETIVfyP SETINet.bat 4 %1 %2 %3 %4 %5
   if not .%SB.Quit%.==.. goto Help


  rem Fix up *.ok/*.no in %1 folder

   call BatFiles\CmdOKNO.bat %1


  rem Display version and instance information

   echo.
   echo.SETINet.bat %SB.ver% %SB.verdate%:
   echo.Refreshing WUs for %2\%3 Instance %4 ...
   echo.

  rem Mark SETINet active in current directory

   echo.SETINet running > SETINet.run


  rem Free requested Drive: for Network Connection

   echo.net use %1 /DELETE ... will fail if not already mapped

   if .%SB.OS%.==.NT. net use %1 /DELETE
   if .%SB.OS%.==.98. net use %1 /DELETE /YES


  rem Establish Network Connection

   if .%SB.OS%.==.NT. net use %1 %2\%3 /PERSISTENT:NO
   if .%SB.OS%.==.98. net use %1 %2\%3 /YES


  rem Verify ReturnTo.vbs is present on remote computer

   call BatFiles\VfyFile.bat SETINet.bat %1\BatFiles ReturnTo.vbs
   if .%SB.Quit%.==.. goto GoRtrnOK
   echo.
   echo.SETINet.bat %SB.ver% %SB.verdate%:
   echo.File ReturnTo.vbs not found in %1\BatFiles ... Terminating
   echo.
   echo.Ensure SETIBuf %SB.ver% %SB.verdate% is installed correctly on %1
   echo.
   pause
   goto GoBACKok


:GoRtrnOK

  rem Save SETINet current directory information on remote computer

   cd > %1\%4\ReturnTo.bat


  rem Switch to mapped drive

   %1

  rem Verify that switch to mapped drive was successful

   if not exist SETINet.run goto GoMAPok
   echo.
   echo.SETINet.bat %SB.ver% %SB.verdate%:
   echo.Cannot Map %1 or cannot switch to %1
   goto BadParam


:GoMAPok

  rem Change to SETI directory  

   cd \

  rem Verify presence of SETICall.bat

   if exist SETICall.bat goto GoCALLok
   echo.
   echo.SETINet.bat %SB.ver% %SB.verdate%:  Cannot find SETICall.bat


:BadParam

   echo.
   echo.Make sure the Drive:, \\Machine, and SETI Path are specified correctly
   echo.
   echo.Parameters received:
   echo.  1.  %1
   echo.  2.  %2
   echo.  3.  %3
   echo.  4.  %4
   if not .%5.==.. echo.  5.  %5
   goto HELP


:GoCALLok

  rem Invoke SETICall.bat (on the remote machine)

   call SETICall.bat %4

  rem Set current directory to Cmd-n folder on remote machine

   cd %4

  rem Fix up ReturnTo.bat

   start /wait wscript ..\BatFiles\ReturnTo.vbs


  rem Reset current drive and directory to original (local machine) SETI folder

   call ReturnTo.bat


  rem Remove ReturnTo.bat on remote machine

   call BatFiles\DelOld.bat %1\%4 ReturnTo.bat


  rem Verify that we returned to the proper directory

   if exist SETINet.run goto GoBACKok
   echo.
   echo.SETINet.bat %SB.ver% %SB.verdate%:
   echo.Could not return to 'Home' folder due to an unknown problem.
   echo.
   pause   


:GoBACKok

  rem Remove SETINet.run signal

   call BatFiles\DelOld.bat . SETINet.run


  rem Remove Network connection

   echo.
   if .%SB.OS%.==.NT. net use %1 /DELETE
   if .%SB.OS%.==.98. net use %1 /DELETE /YES


:Continue
