@echo off

rem WUSet.bat:  SETIBuf Service routine -- Activates/Deactivates WU Buffers
rem For version info, see BatFiles\SBVer.bat

if .%1.==./?. goto Help
if not .%1.==.?. goto NoHelp


:Help

   echo.
   echo.WUSet.bat %SB.ver% %SB.verdate% Expected Parameters:
   echo.
   echo.  1.  Instance base (e.g., Cmd-1); a folder with this name is tested for
   echo.  2.  OK or NO, specifying whether WU Buffers are to be activated (OK) or
   echo.      deactivated (NO)
   echo.  3.  The maximum WU Buffer number to activate or deactivate (1 through 9)
   echo.
   echo.  The SETI folder is assumed to be the current directory
   echo.
   echo. Function:  Mark specified WU Buffers active or inactive.
   echo.            If marking buffers active, then:
   echo.              Call SETI.bat to process Work Unit(s)
   echo.              Call SETISend.bat to send in any completed
   echo.
   pause
   goto Continue

:NoHelp


  rem Test for presence of BatFiles\SETIVfy.bat

   if exist BatFiles\SETIVfy.bat goto VFYok
   echo.
   echo.WUSet.bat %SB.ver% %SB.verdate%:
   echo.Improper installation:  cannot find BatFiles\SETIVfy.bat
   echo.
   set SB.Quit=WUSet.bat_cannot_find_SETIVfy.bat
   pause
   goto Continue

:VFYok


  rem Verify installation   

   call BatFiles\SETIVfy.bat SETI.bat
   if not .%SB.Quit%.==.. goto Continue


  rem Verify Parameters

   call BatFiles\SETIVfyP WUSet.bat 3 %1 %2 %3 %4
   if not .%SB.Quit%.==.. goto Help


  rem Fix up *.ok/*.no in %1 folder

   call BatFiles\CmdOKNO.bat %1


  rem Verify that %2 is OK or NO (case-insensitive)

   set WUSet.old=
   if .%2.==.OK. set WUSet.old=no
   if .%2.==.ok. set WUSet.old=no
   if .%2.==.Ok. set WUSet.old=no
   if .%2.==.oK. set WUSet.old=no
   if .%2.==.NO. set WUSet.old=ok
   if .%2.==.no. set WUSet.old=ok
   if .%2.==.No. set WUSet.old=ok
   if .%2.==.nO. set WUSet.old=ok
   if .%WUSet.old%.==.. goto BadP2
   set WUSet.new=ok
   if .%WUSet.old%.==.ok. set WUSet.new=no


  rem Verify that %3 is 1 through 9

   if .%3.==.1. goto P3ok
   if .%3.==.2. goto P3ok
   if .%3.==.3. goto P3ok
   if .%3.==.4. goto P3ok
   if .%3.==.5. goto P3ok
   if .%3.==.6. goto P3ok
   if .%3.==.7. goto P3ok
   if .%3.==.8. goto P3ok
   if not .%3.==.9. goto BadP3

:P3ok


  rem Ensure that directory %1 exists (if not, display an error)

   call BatFiles\Vfy1OK.bat WUSet.bat %1 *.*
   if not .%SB.Quit%.==.. goto Continue


  rem Display Version and Instance information

   echo.
   echo.SETIBuf %SB.ver% %SB.verdate%:  SETI@home Work Unit Buffering
   echo.WUSet.bat %SB.ver% %SB.verdate%:  Instance %1
   if .%WUSet.New%.==.ok. echo.Activating WU Buffers 1 through %3 ...
   if .%WUSet.New%.==.no. echo.Deactivating WU Buffers 1 through %3 ...
   echo.


  rem Rename the *.ok to *.no, or vice versa (finally!)

   if exist %1\1\SETI.%WUSet.old% ren %1\1\SETI.%WUSet.old% SETI.%WUSet.new%
   if .%3.==.1. goto RunIfOK
   if exist %1\2\SETI.%WUSet.old% ren %1\2\SETI.%WUSet.old% SETI.%WUSet.new%
   if .%3.==.2. goto RunIfOK
   if exist %1\3\SETI.%WUSet.old% ren %1\3\SETI.%WUSet.old% SETI.%WUSet.new%
   if .%3.==.3. goto RunIfOK
   if exist %1\4\SETI.%WUSet.old% ren %1\4\SETI.%WUSet.old% SETI.%WUSet.new%
   if .%3.==.4. goto RunIfOK
   if exist %1\5\SETI.%WUSet.old% ren %1\5\SETI.%WUSet.old% SETI.%WUSet.new%
   if .%3.==.5. goto RunIfOK
   if exist %1\6\SETI.%WUSet.old% ren %1\6\SETI.%WUSet.old% SETI.%WUSet.new%
   if .%3.==.6. goto RunIfOK
   if exist %1\7\SETI.%WUSet.old% ren %1\7\SETI.%WUSet.old% SETI.%WUSet.new%
   if .%3.==.7. goto RunIfOK
   if exist %1\8\SETI.%WUSet.old% ren %1\8\SETI.%WUSet.old% SETI.%WUSet.new%
   if .%3.==.8. goto RunIfOK
   if exist %1\9\SETI.%WUSet.old% ren %1\9\SETI.%WUSet.old% SETI.%WUSet.new%


:RunIfOK

  rem We can stop now if NO was specified

   if .%WUSet.new%.==.no. goto Continue


  rem Invoke SETI.bat followed by SETISend.bat, and Continue

   call SETI.bat %1
   if not .%SB.Quit%.==.User_replied_Y_to_Terminate_batch_job_(Y/N)?. call SETISend.bat %1
   goto Continue


:BadP2

   echo.
   echo.WUSet.bat %SB.ver% %SB.verdate%:
   echo.Improper invocation:  Parameter 2, expected OK or NO
   echo.                                   received %2
   echo.
   set SB.Quit=WUSet.bat_Parameter_2_incorrect_value
   call BatFiles\StopAll.bat WUSet.bat
   goto Continue 


:BadP3

   echo.
   echo.WUSet.bat %SB.ver% %SB.verdate%:
   echo.Improper invocation:  Parameter 3, expected 1 through 9
   echo.                                   received %3
   echo.
   set SB.Quit=WUSet.bat_Parameter_3_incorrect_value
   call BatFiles\StopAll.bat WUSet.bat


:Continue

   set WUSet.old=
   set WUSet.new=
